@@ -20,9 +20,10 @@ public:
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
     void checkUrl(const QUrl &url);
-    void getDownloadUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     inline bool loginSupported() const { return false; }
     inline bool recaptchaRequired() const { return false; }
+    bool cancelCurrentOperation();
 
 private:
     void getDownloadLink(const QUrl &url);
@@ -35,6 +36,9 @@ private slots:
     void updateWaitTime();
     void onWaitFinished();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QTimer *m_waitTimer;
     int m_waitTime;
